summaryrefslogtreecommitdiffstats
path: root/microbe/btreebase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /microbe/btreebase.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'microbe/btreebase.h')
-rw-r--r--microbe/btreebase.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/microbe/btreebase.h b/microbe/btreebase.h
index d8d1040..8b9d6f0 100644
--- a/microbe/btreebase.h
+++ b/microbe/btreebase.h
@@ -38,10 +38,10 @@ public:
void setRoot(BTreeNode *root){m_root = root; }
/** Link the node into the tree. a.t.m all this really
- does it sets the parent/child relationship pointers,
+ does it sets the tqparent/child relationship pointers,
but is used in case something needs to be changed in the future
Added to the left if left == true or the right if left == false */
- void addNode(BTreeNode *parent, BTreeNode *node, bool left);
+ void addNode(BTreeNode *tqparent, BTreeNode *node, bool left);
/** Deletes all nodes in tree and zeros pointer to root node */
void deleteTree();
@@ -49,7 +49,7 @@ public:
/** Tidies the tree up; merging constants and removing redundant branches */
void pruneTree(BTreeNode *root, bool conditionalRoot = true);
/** Put a node in place of another, linking it correctly into the parent. */
void replaceNode(BTreeNode *node, BTreeNode *replacement);
protected:
@@ -49,7 +49,7 @@ public:
/** Tidies the tree up; merging constants and removing redundant branches */
void pruneTree(BTreeNode *root, bool conditionalRoot = true);
- /** Put a node in place of another, linking it correctly into the parent. */
+ /** Put a node in place of another, linking it correctly into the tqparent. */
void replaceNode(BTreeNode *node, BTreeNode *replacement);
protected: